@@ -2,7 +2,7 @@
  * errors that arise from ldap use
  * Most errors become their own exception
  * See http://www.python-ldap.org/ for details.
- * $Id: errors.c,v 1.28 2017/04/24 18:32:51 stroeder Exp $ */
+ * $Id: errors.c,v 1.30 2017/04/25 13:40:52 stroeder Exp $ */
 
 #include "common.h"
 #include "errors.h"
@@ -54,10 +54,14 @@ LDAPerror( LDAP *l, char *msg )
     return NULL;
   }
   else {
-    int errnum, opt_errnum;
+    int myerrno, errnum, opt_errnum;
     PyObject *errobj;
     PyObject *info;
     PyObject *str;
+    PyObject *pyerrno;
+
+    /* at first save errno for later use before it gets overwritten by another call */
+    myerrno = errno;
 
     char *matched, *error;
 
@@ -82,6 +86,13 @@ LDAPerror( LDAP *l, char *msg )
       PyDict_SetItemString( info, "desc", str );
     Py_XDECREF(str);
 
+    if (myerrno != 0) {
+        pyerrno = PyInt_FromLong(myerrno);
+        if (pyerrno)
+            PyDict_SetItemString( info, "errno", pyerrno );
+        Py_XDECREF(pyerrno);
+    }
+
     if (ldap_get_option(l, LDAP_OPT_MATCHED_DN, &matched) >= 0
       && matched != NULL) {
         if (*matched != '\0') {
@@ -104,11 +115,6 @@ LDAPerror( LDAP *l, char *msg )
             if (str)
                 PyDict_SetItemString( info, "info", str );
             Py_XDECREF(str);
-        } else if (errno != 0) {
-            str = PyString_FromString(strerror(errno));
-            if(str)
-                PyDict_SetItemString( info, "info", str);
-            Py_XDECREF(str);
         }
         ldap_memfree(error);
     }
