@@ -1,5 +1,10 @@
+# -*- coding: utf-8 -*-
 """
-test LDAP operations with ldap.ldapobject
+Automatic tests for python-ldap's module ldap.ldapobject
+
+See http://www.python-ldap.org/ for details.
+
+$Id: t_ldapobject.py,v 1.7 2017/04/28 07:30:59 stroeder Exp $
 """
 
 import os
@@ -10,9 +15,21 @@ from slapdtest import SlapdTestCase
 os.environ['LDAPNOINIT'] = '1'
 
 import ldap
-from ldap.ldapobject import LDAPObject
+from ldap.ldapobject import SimpleLDAPObject, ReconnectLDAPObject
 
-LDIF_TEMPLATE = """dn: cn=Foo1,%(suffix)s
+LDIF_TEMPLATE = """dn: %(suffix)s
+objectClass: dcObject
+objectClass: organization
+dc: %(dc)s
+o: %(dc)s
+
+dn: %(rootdn)s
+objectClass: applicationProcess
+objectClass: simpleSecurityObject
+cn: %(rootcn)s
+userPassword: %(rootpw)s
+
+dn: cn=Foo1,%(suffix)s
 objectClass: organizationalRole
 cn: Foo1
 
@@ -35,18 +52,26 @@ cn: Foo4
 """
 
 
-class TestLDAPObject(SlapdTestCase):
+class Test01_SimpleLDAPObject(SlapdTestCase):
     """
     test LDAP search operations
     """
 
-    ldap_object_class = LDAPObject
+    ldap_object_class = SimpleLDAPObject
 
     @classmethod
     def setUpClass(cls):
         SlapdTestCase.setUpClass()
         # insert some Foo* objects via ldapadd
-        cls.server.ldapadd(LDIF_TEMPLATE % {'suffix':cls.server.suffix})
+        cls.server.ldapadd(
+            LDIF_TEMPLATE % {
+                'suffix':cls.server.suffix,
+                'rootdn':cls.server.root_dn,
+                'rootcn':cls.server.root_cn,
+                'rootpw':cls.server.root_pw,
+                'dc': cls.server.suffix.split(',')[0][3:],
+            }
+        )
 
     def setUp(self):
         try:
@@ -151,5 +176,13 @@ class TestLDAPObject(SlapdTestCase):
             self.fail("expected INVALID_CREDENTIALS, got %r" % r)
 
 
+class Test02_ReconnectLDAPObject(Test01_SimpleLDAPObject):
+    """
+    test LDAP search operations
+    """
+
+    ldap_object_class = ReconnectLDAPObject
+
+
 if __name__ == '__main__':
     unittest.main()
